# OSTEP (Korean Version)

```{image} https://github.com/remzi-arpacidusseau/ostep-translations/raw/master/korean/cover.jpg
:align: center
```

Welcome to the Korean translation of OSTEP, v0.91.
Translation by Youjip Won, Minkyu Park, Sungjin Lee.

Interested in buying?

- [Hardcover](http://www.hongpub.co.kr/sub.php?goPage=view_product&flashpage=&Code=20170523160625)
- [Softcover](http://www.hongpub.co.kr/sub.php?goPage=view_product&flashpage=&Code=20170327120039)

Book chapters, available freely here:

| intro                                                           | virtualization                                                            |                                                                              | concurrency                                                                     | persistence                                                                         |
| --------------------------------------------------------------- | ------------------------------------------------------------------------- | ---------------------------------------------------------------------------- | ------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------- |
| [Preface](http://ostep.org/Korean/00-preface.pdf)               | 3 [Dialogue](http://ostep.org/Korean/03-dialogue-virtualization.pdf)      | 12 [Dialogue](http://ostep.org/Korean/12-dialogue-vm.pdf)                    | 25 [Dialogue](http://ostep.org/Korean/25_dialogue-concurrency.pdf)              | 35 [Dialogue](http://ostep.org/Korean/35_dialogue-persistence.pdf)                  |
| [Preface-Translate](http://ostep.org/Korean/00-preface-tx.pdf)  | 4 [Processes](http://ostep.org/Korean/04-cpu-intro.pdf)                   | 13 [Address Spaces](http://ostep.org/Korean/13-vm-intro.pdf)                 | 26 [Concurrency and Threads](http://ostep.org/Korean/26_threads-intro.pdf)      | 36 [I/O Devices](http://ostep.org/Korean/36_file-devices.pdf)                       |
| [TOC](http://ostep.org/Korean/00-toc.pdf)                       | 5 [Process API](http://ostep.org/Korean/05-cpu-api.pdf)                   | 14 [Memory API](http://ostep.org/Korean/14-vm-api.pdf)                       | 27 [Thread API](http://ostep.org/Korean/27_threads-api.pdf)                     | 37 [Hard Disk Drives](http://ostep.org/Korean/37_file_disks.pdf)                    |
| 1 [Dialogue](http://ostep.org/Korean/01-dialogue-threeeasy.pdf) | 6 [Direct Execution](http://ostep.org/Korean/06-cpu-mechanisms.pdf)       | 15 [Address Translation](http://ostep.org/Korean/15-vm-mechanism.pdf)        | 28 [Locks](http://ostep.org/Korean/28_threads-locks.pdf)                        | 38 [Redundant Disk Arrays (RAID)](http://ostep.org/Korean/38_RAID.pdf)              |
| 2 [Introduction](http://ostep.org/Korean/02-intro.pdf)          | 7 [CPU Scheduling](http://ostep.org/Korean/07-cpu-sched.pdf)              | 16 [Segmentation](http://ostep.org/Korean/16-vm-segmentation.pdf)            | 29 [Locked Data Structures](http://ostep.org/Korean/29_threads-locks-usage.pdf) | 39 [Files and Directories](http://ostep.org/Korean/39_interlude-file-directory.pdf) |
|                                                                 | 8 [Multi-level Feedback](http://ostep.org/Korean/08-cpu-sched-mlfq.pdf)   | 17 [Free Space Management](http://ostep.org/Korean/17-vm-freespace.pdf)      | 30 [Condition Variables](http://ostep.org/Korean/30_threads-cv.pdf)             | 40 [File System Implementation](http://ostep.org/Korean/40_FS-implementation.pdf)   |
|                                                                 | 9 [Lottery Scheduling](http://ostep.org/Korean/09-cpu-sched-lottery.pdf)  | 18 [Introduction to Paging](http://ostep.org/Korean/18-vm-paging.pdf)        | 31 [Semaphores](http://ostep.org/Korean/31_threads-sema.pdf)                    | 41 [Fast File System (FFS)](http://ostep.org/Korean/41_FFS.pdf)                     |
|                                                                 | 10 [Multi-CPU Scheduling](http://ostep.org/Korean/10-cpu-sched-multi.pdf) | 19 [Translation Lookaside Buffers](http://ostep.org/Korean/19_vm-tlbs.pdf)   | 32 [Concurrency Bugs](http://ostep.org/Korean/32_threads-bugs.pdf)              | 42 [FSCK and Journaling](http://ostep.org/Korean/42_crash-consistency.pdf)          |
|                                                                 | 11 [Summary](http://ostep.org/Korean/11-cpu-dialogue.pdf)                 | 20 [Advanced Page Tables](http://ostep.org/Korean/20_vm-smalltables.pdf)     | 33 [Event-based Concurrency](http://ostep.org/Korean/33_threads-events.pdf)     | 43 [Log-Structured File System (LFS)](http://ostep.org/Korean/43_LFS.pdf)           |
|                                                                 |                                                                           | 21 [Swapping: Mechanisms](http://ostep.org/Korean/21_vm-beyondphys.pdf)      | 34 [Summary](http://ostep.org/Korean/34_threads_dialogue.pdf)                   | 44 [Data Integrity and Protection](http://ostep.org/Korean/44_data-integrity.pdf)   |
|                                                                 |                                                                           | 22 [Swapping: Policies](http://ostep.org/Korean/22_vm-beyondphys-policy.pdf) |                                                                                 | 45 [Summary](http://ostep.org/Korean/45_file-dialogue.pdf)                          |
|                                                                 |                                                                           | 23 [Case Study: VAX](http://ostep.org/Korean/23_vm-vax.pdf)                  |                                                                                 | 46 [Dialogue](http://ostep.org/Korean/46_dialogue-distribution.pdf)                 |
|                                                                 |                                                                           | 24 [Summary](http://ostep.org/Korean/24_vm-dialogue.pdf)                     |                                                                                 | 47 [Distributed Systems](http://ostep.org/Korean/47_dist-intro.pdf)                 |
|                                                                 |                                                                           |                                                                              |                                                                                 | 48 [Network File System (NFS)](http://ostep.org/Korean/48_NFS.pdf)                  |
|                                                                 |                                                                           |                                                                              |                                                                                 | 49 [Andrew File System (AFS)](http://ostep.org/Korean/49_AFS.pdf)                   |
|                                                                 |                                                                           |                                                                              |                                                                                 | 50 [Summary](http://ostep.org/Korean/50_dist-dialogue.pdf)                          |
